@@ -60,13 +60,23 @@ class FigpackView:
 
         # determine upload
         if upload is None:
-            upload = os.environ.get("FIGPACK_UPLOAD") == "1"
-        else:
-            if upload is True and ephemeral is True:
+            if os.environ.get("FIGPACK_UPLOAD") == "1":
+                upload = True
+            elif os.environ.get("FIGPACK_UPLOAD") == "0":
+                upload = False
+
+        if upload is True:
+            if ephemeral is True:
                 # ephemeral is reserved for the case where we don't specify upload
                 # and we are in a notebook in a remote environment such as
                 # colab or jupyterhub
-                raise ValueError("ephemeral cannot be set if upload is set")
+                raise ValueError(
+                    "ephemeral cannot be set to True if upload is set to True"
+                )
+            else:
+                ephemeral = (
+                    False  # if we excplicitly set upload=True, force ephemeral=False
+                )
 
         # determine inline
         if inline is None:
@@ -82,9 +92,14 @@ class FigpackView:
             open_in_browser = os.environ.get("FIGPACK_OPEN_IN_BROWSER") == "1"
 
         # determine ephemeral
-        if ephemeral is None:
+        if ephemeral is None and not upload:
             ephemeral = False  # default to False
-            if _is_in_notebook():
+            if os.environ.get("FIGPACK_REMOTE_ENV") == "1":
+                ephemeral = True
+                upload = True
+            elif os.environ.get("FIGPACK_REMOTE_ENV") == "0":
+                ephemeral = False
+            elif _is_in_notebook():
                 if _is_in_colab():
                     # if we are in a notebook and in colab, we should show as uploaded ephemeral
                     print("Detected Google Colab notebook environment.")
@@ -100,6 +115,12 @@ class FigpackView:
         if _dev is None:
             _dev = os.environ.get("FIGPACK_DEV") == "1"
 
+        if port is None and os.environ.get("FIGPACK_PORT"):
+            try:
+                port = int(os.environ.get("FIGPACK_PORT"))
+            except Exception:
+                pass
+
         # determine wait_for_input
         if wait_for_input is None:
             wait_for_input = not _is_in_notebook()
@@ -145,7 +166,7 @@ class FigpackView:
             _local_figure_name=_local_figure_name if _dev else None,
         )
 
-    def save(self, output_path: str, *, title: str) -> None:
+    def save(self, output_path: str, *, title: str, description: str = "") -> None:
         """
         Save as figure either to a folder or to a .tar.gz file
         Args:
@@ -153,13 +174,13 @@ class FigpackView:
         """
         from ._save_figure import _save_figure
 
-        _save_figure(self, output_path, title=title)
+        _save_figure(self, output_path, title=title, description=description)
 
-    def _write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: Group) -> None:
         """
         Write the view data to a Zarr group. Must be implemented by subclasses.
 
         Args:
             group: Zarr group to write data into
         """
-        raise NotImplementedError("Subclasses must implement _write_to_zarr_group")
+        raise NotImplementedError("Subclasses must implement write_to_zarr_group")
