@@ -71,6 +71,13 @@ class TimeseriesGraph(FigpackView):
             width: Line width
             dash: Dash pattern as [dash_length, gap_length]
         """
+        if isinstance(t, list):
+            t = np.array(t)
+        if isinstance(y, list):
+            y = np.array(y)
+        assert t.ndim == 1, "Time array must be 1-dimensional"
+        assert y.ndim == 1, "Y array must be 1-dimensional"
+        assert len(t) == len(y), "Time and Y arrays must have the same length"
         self._series.append(
             TGLineSeries(name=name, t=t, y=y, color=color, width=width, dash=dash)
         )
@@ -96,6 +103,13 @@ class TimeseriesGraph(FigpackView):
             radius: Marker radius
             shape: Marker shape ("circle", "square", etc.)
         """
+        if isinstance(t, list):
+            t = np.array(t)
+        if isinstance(y, list):
+            y = np.array(y)
+        assert t.ndim == 1, "Time array must be 1-dimensional"
+        assert y.ndim == 1, "Y array must be 1-dimensional"
+        assert len(t) == len(y), "Time and Y arrays must have the same length"
         self._series.append(
             TGMarkerSeries(name=name, t=t, y=y, color=color, radius=radius, shape=shape)
         )
@@ -119,6 +133,18 @@ class TimeseriesGraph(FigpackView):
             color: Fill color
             alpha: Transparency (0-1)
         """
+        if isinstance(t_start, list):
+            t_start = np.array(t_start)
+        if isinstance(t_end, list):
+            t_end = np.array(t_end)
+        assert t_start.ndim == 1, "Start time array must be 1-dimensional"
+        assert t_end.ndim == 1, "End time array must be 1-dimensional"
+        assert len(t_start) == len(
+            t_end
+        ), "Start and end time arrays must have the same length"
+        assert np.all(
+            t_start <= t_end
+        ), "Start times must be less than or equal to end times"
         self._series.append(
             TGIntervalSeries(
                 name=name, t_start=t_start, t_end=t_end, color=color, alpha=alpha
@@ -135,6 +161,9 @@ class TimeseriesGraph(FigpackView):
         channel_names: Optional[List[str]] = None,
         colors: Optional[List[str]] = None,
         width: float = 1.0,
+        channel_spacing: Optional[float] = None,
+        auto_channel_spacing: Optional[float] = None,
+        timestamps_for_inserting_nans: Optional[np.ndarray] = None,
     ) -> None:
         """
         Add a uniform timeseries to the graph with optional multi-channel support
@@ -147,7 +176,12 @@ class TimeseriesGraph(FigpackView):
             channel_names: Optional list of channel names
             colors: Optional list of colors for each channel
             width: Line width
+            channel_spacing: Vertical spacing between channels
+            auto_channel_spacing: sets channel spacing to this multiple of the estimated RMS noise level
+            timestamps_for_inserting_nans: Optional array of timestamps used to determine where to insert NaNs in the data
         """
+        if isinstance(data, list):
+            data = np.array(data)
         self._series.append(
             TGUniformSeries(
                 name=name,
@@ -157,10 +191,13 @@ class TimeseriesGraph(FigpackView):
                 channel_names=channel_names,
                 colors=colors,
                 width=width,
+                channel_spacing=channel_spacing,
+                auto_channel_spacing=auto_channel_spacing,
+                timestamps_for_inserting_nans=timestamps_for_inserting_nans,
             )
         )
 
-    def _write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: Group) -> None:
         """
         Write the graph data to a Zarr group
 
@@ -170,13 +207,13 @@ class TimeseriesGraph(FigpackView):
         for series in self._series:
             series_group = group.create_group(series.name)
             if isinstance(series, TGLineSeries):
-                series._write_to_zarr_group(series_group)
+                series.write_to_zarr_group(series_group)
             elif isinstance(series, TGMarkerSeries):
-                series._write_to_zarr_group(series_group)
+                series.write_to_zarr_group(series_group)
             elif isinstance(series, TGIntervalSeries):
-                series._write_to_zarr_group(series_group)
+                series.write_to_zarr_group(series_group)
             elif isinstance(series, TGUniformSeries):
-                series._write_to_zarr_group(series_group)
+                series.write_to_zarr_group(series_group)
             else:
                 raise ValueError(f"Unknown series type: {type(series)}")
 
@@ -215,7 +252,7 @@ class TGLineSeries:
         self.width = width
         self.dash = dash
 
-    def _write_to_zarr_group(
+    def write_to_zarr_group(
         self,
         group: Group,
     ) -> None:
@@ -248,7 +285,7 @@ class TGMarkerSeries:
         self.radius = radius
         self.shape = shape
 
-    def _write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: Group) -> None:
         """
         Write the marker series data to a Zarr dataset
 
@@ -287,7 +324,7 @@ class TGIntervalSeries:
         self.color = color
         self.alpha = alpha
 
-    def _write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: Group) -> None:
         """
         Write the interval series data to a Zarr dataset
 
@@ -312,6 +349,9 @@ class TGUniformSeries:
         channel_names: Optional[List[str]] = None,
         colors: Optional[List[str]] = None,
         width: float = 1.0,
+        channel_spacing: Optional[float] = None,
+        auto_channel_spacing: Optional[float] = None,
+        timestamps_for_inserting_nans: Optional[np.ndarray] = None,
     ):
         assert sampling_frequency_hz > 0, "Sampling frequency must be positive"
 
@@ -332,6 +372,30 @@ class TGUniformSeries:
         self.sampling_frequency_hz = sampling_frequency_hz
         self.data = data.astype(np.float32)  # Ensure float32 for efficiency
 
+        if timestamps_for_inserting_nans is not None:
+            self.data = insert_nans_based_on_timestamps(
+                self.data,
+                start_time_sec=start_time_sec,
+                sampling_frequency_hz=sampling_frequency_hz,
+                timestamps=timestamps_for_inserting_nans,
+            )
+
+        if auto_channel_spacing is not None:
+            if channel_spacing is not None:
+                raise ValueError(
+                    "Specify either channel_spacing or auto_channel_spacing, not both."
+                )
+            # Estimate RMS noise level across all channels using median absolute deviation
+            # Use nanmedian to handle NaN values properly
+            mad = np.nanmedian(
+                np.abs(self.data - np.nanmedian(self.data, axis=0)), axis=0
+            )
+            rms_estimate = mad / 0.6745  # Convert MAD to RMS estimate
+            channel_spacing = auto_channel_spacing * np.nanmedian(rms_estimate)
+            if channel_spacing <= 0 or np.isnan(channel_spacing):
+                channel_spacing = 1.0  # Fallback to default spacing if estimate fails
+        self.channel_spacing = channel_spacing
+
         # Set channel names
         if channel_names is None:
             if n_channels == 1:
@@ -492,7 +556,7 @@ class TGUniformSeries:
         else:  # len(shape) == 3
             return (chunk_timepoints, 2, n_channels)
 
-    def _write_to_zarr_group(self, group: Group) -> None:
+    def write_to_zarr_group(self, group: Group) -> None:
         """
         Write the uniform series data to a Zarr group
 
@@ -512,6 +576,9 @@ class TGUniformSeries:
         group.attrs["n_timepoints"] = n_timepoints
         group.attrs["n_channels"] = n_channels
 
+        if self.channel_spacing is not None:
+            group.attrs["channel_spacing"] = float(self.channel_spacing)
+
         # Store original data with optimal chunking
         original_chunks = self._calculate_optimal_chunk_size(self.data.shape)
         group.create_dataset(
@@ -535,3 +602,25 @@ class TGUniformSeries:
                 data=downsampled_array,
                 chunks=ds_chunks,
             )
+
+
+def insert_nans_based_on_timestamps(
+    x: np.ndarray,
+    *,
+    start_time_sec: float,
+    sampling_frequency_hz: float,
+    timestamps: np.ndarray,
+):
+    end_timestamps = timestamps[-1]
+    ret_length = int((end_timestamps - start_time_sec) * sampling_frequency_hz) + 1
+
+    # Handle both 1D and 2D (multi-channel) data
+    if x.ndim == 1:
+        ret = np.nan * np.ones((ret_length,), dtype=x.dtype)
+    else:  # x.ndim == 2
+        n_channels = x.shape[1]
+        ret = np.nan * np.ones((ret_length, n_channels), dtype=x.dtype)
+
+    indices = ((timestamps - start_time_sec) * sampling_frequency_hz).astype(int)
+    ret[indices] = x
+    return ret
