@@ -2,10 +2,13 @@ from .Box import Box
 from .DataFrame import DataFrame
 from .Gallery import Gallery
 from .GalleryItem import GalleryItem
+from .Iframe import Iframe
 from .Image import Image
 from .LayoutItem import LayoutItem
 from .Markdown import Markdown
 from .MatplotlibFigure import MatplotlibFigure
+from .MountainLayout import MountainLayout
+from .MountainLayoutItem import MountainLayoutItem
 from .MultiChannelTimeseries import MultiChannelTimeseries
 from .Spectrogram import Spectrogram
 from .Splitter import Splitter
